(* driver.sml *)

structure Lexer =
struct 

  (* fun lex: string -> unit
   *   lex fileName : lexically analyzes contents of file filename, printing
   *   resulting tokens (which are strings) on standard output, one token per line.
   *   If error occurs, prints "*** Error termination ***" and terminates. *)
  fun lex fileName =
      let val instrm = TextIO.openIn fileName
	  fun get _ = TextIO.input instrm
	  val lexer = Mlex.makeLexer get
	  fun do_it() =
	      let val t = lexer()
	       in print t; print "\n";
		   if substring(t,0,3)="EOF" then () else do_it()
	      end
              handle ErrorMsg.Error =>
                print "*** Error termination ***\n" 
       in ErrorMsg.reset(fileName);  (* reset line numbers, etc. *)
          do_it();
          TextIO.flushOut (TextIO.stdOut);
	  TextIO.closeIn instrm
      end

  (* driver: string * string list -> OS.Process.status
   *   driver is to be used as the second argument of SMLofNJ.exportFn
   *   to create a stand-alone lexer image *)
  fun driver(_: string, args : string list): OS.Process.status =
      (case args
         of nil => (print "lexer requires one argument\n";
                    TextIO.flushOut(TextIO.stdOut);
                    OS.Process.failure)
          | arg1::_ => (lex arg1; OS.Process.success))

end (* structure Lexer *)
