(* tokens.sig *)

signature Tiger_TOKENS =
sig
  type pos (* = int *)
       (* character position in the input stream *)
  type token
       (* the representation of lexical tokens *)

  (* token construction functions.  The pos parameters is expected to be
   * the initial character position of the token and the character position
   * immediately following the token *)

  val TYPE:  pos * pos -> token
  val VAR:  pos * pos -> token
  val FUNCTION:  pos * pos -> token
  val BREAK:  pos * pos -> token
  val OF:  pos * pos -> token
  val END:  pos * pos -> token
  val IN:  pos * pos -> token
  val NIL:  pos * pos -> token
  val LET:  pos * pos -> token
  val DO:  pos * pos -> token
  val TO:  pos * pos -> token
  val FOR:  pos * pos -> token
  val WHILE:  pos * pos -> token
  val ELSE:  pos * pos -> token
  val THEN:  pos * pos -> token
  val IF:  pos * pos -> token
  val ARRAY:  pos * pos -> token
  val ASSIGN:  pos * pos -> token
  val OR:  pos * pos -> token
  val AND:  pos * pos -> token
  val GE:  pos * pos -> token
  val GT:  pos * pos -> token
  val LE:  pos * pos -> token
  val LT:  pos * pos -> token
  val NEQ:  pos * pos -> token
  val EQ:  pos * pos -> token
  val DIVIDE:  pos * pos -> token
  val TIMES:  pos * pos -> token
  val MINUS:  pos * pos -> token
  val PLUS:  pos * pos -> token
  val DOT:  pos * pos -> token
  val RBRACE:  pos * pos -> token
  val LBRACE:  pos * pos -> token
  val RBRACK:  pos * pos -> token
  val LBRACK:  pos * pos -> token
  val RPAREN:  pos * pos -> token
  val LPAREN:  pos * pos -> token
  val SEMICOLON:  pos * pos -> token
  val COLON:  pos * pos -> token
  val COMMA:  pos * pos -> token
  val STRING: string *  pos * pos -> token
  val INT: int *  pos * pos -> token
  val ID: string *  pos * pos -> token
  val EOF:  pos * pos -> token

end (* signature Tiger_TOKENS *)
